from vespa.configuration.vt import VT

def allow(*c, **kwargs) -> VT: ...
def bcp(*c, **kwargs) -> VT: ...
def block_change(*c, **kwargs) -> VT: ...
def delay(*c, **kwargs) -> VT: ...
def deployment(*c, **kwargs) -> VT: ...
def dev(*c, **kwargs) -> VT: ...
def endpoint(*c, **kwargs) -> VT: ...
def endpoints(*c, **kwargs) -> VT: ...
def group(*c, **kwargs) -> VT: ...
def instance(*c, **kwargs) -> VT: ...
def nodes(*c, **kwargs) -> VT: ...
def parallel(*c, **kwargs) -> VT: ...
def prod(*c, **kwargs) -> VT: ...
def region(*c, **kwargs) -> VT: ...
def staging(*c, **kwargs) -> VT: ...
def steps(*c, **kwargs) -> VT: ...
def test_(*c, **kwargs) -> VT: ...
def tester(*c, **kwargs) -> VT: ...
def upgrade(*c, **kwargs) -> VT: ...
