from vespa.configuration.vt import VT

def description(*c, **kwargs) -> VT: ...
def dimensions(*c, **kwargs) -> VT: ...
def field(*c, **kwargs) -> VT: ...
def match_(*c, **kwargs) -> VT: ...
def query_profile(*c, **kwargs) -> VT: ...
def query_profile_type(*c, **kwargs) -> VT: ...
def ref(*c, **kwargs) -> VT: ...
def strict(*c, **kwargs) -> VT: ...
